package main

import (
	"fmt"
	"io"
	"net/http"
	"regexp"
)

const version = "1.0.5"
const versionUrl = "https://git.burkey.co/eburk/epochcli/raw/branch/master/version.go"

func needUpdate() (bool, error) {
	resp, err := http.Get(versionUrl)
	if err != nil {
		return false, fmt.Errorf("unable to get version file: %v", err)
	}
	defer resp.Body.Close()

	if resp.StatusCode != http.StatusOK {
		return false, fmt.Errorf("failed to download update, status code: %d", resp.StatusCode)
	}

	b, err := io.ReadAll(resp.Body)
	if err != nil {
		return false, fmt.Errorf("unable to read response body: %v", err)
	}

	re := regexp.MustCompile(`const version = "([\d.]+)"`)
	ver := re.FindStringSubmatch(string(b))
	if len(ver) < 2 || ver[1] == "" {
		return false, fmt.Errorf("unable to find version in response")
	}

	return ver[1] != version, nil
}
